@@ -9,6 +9,7 @@ import enum
 import functools
 import inspect
 import socket
+import sys
 import warnings
 from asyncio import AbstractEventLoop, AbstractEventLoopPolicy
 from collections.abc import (
@@ -53,17 +54,17 @@ from pytest import (
     StashKey,
 )
 
+if sys.version_info >= (3, 10):
+    from typing import ParamSpec
+else:
+    from typing_extensions import ParamSpec
+
+
 _ScopeName = Literal["session", "package", "module", "class", "function"]
 _T = TypeVar("_T")
-
-SimpleFixtureFunction = TypeVar(
-    "SimpleFixtureFunction", bound=Callable[..., Awaitable[object]]
-)
-FactoryFixtureFunction = TypeVar(
-    "FactoryFixtureFunction", bound=Callable[..., AsyncIterator[object]]
-)
-FixtureFunction = Union[SimpleFixtureFunction, FactoryFixtureFunction]
-FixtureFunctionMarker = Callable[[FixtureFunction], FixtureFunction]
+_R = TypeVar("_R", bound=Union[Awaitable[Any], AsyncIterator[Any]])
+_P = ParamSpec("_P")
+FixtureFunction = Callable[_P, _R]
 
 
 class PytestAsyncioError(Exception):
@@ -107,11 +108,17 @@ def pytest_addoption(parser: Parser, pluginmanager: PytestPluginManager) -> None
         help="default scope of the asyncio event loop used to execute async fixtures",
         default=None,
     )
+    parser.addini(
+        "asyncio_default_test_loop_scope",
+        type="string",
+        help="default scope of the asyncio event loop used to execute tests",
+        default="function",
+    )
 
 
 @overload
 def fixture(
-    fixture_function: FixtureFunction,
+    fixture_function: FixtureFunction[_P, _R],
     *,
     scope: _ScopeName | Callable[[str, Config], _ScopeName] = ...,
     loop_scope: _ScopeName | None = ...,
@@ -123,7 +130,7 @@ def fixture(
         | None
     ) = ...,
     name: str | None = ...,
-) -> FixtureFunction: ...
+) -> FixtureFunction[_P, _R]: ...
 
 
 @overload
@@ -140,14 +147,17 @@ def fixture(
         | None
     ) = ...,
     name: str | None = None,
-) -> FixtureFunctionMarker: ...
+) -> Callable[[FixtureFunction[_P, _R]], FixtureFunction[_P, _R]]: ...
 
 
 def fixture(
-    fixture_function: FixtureFunction | None = None,
+    fixture_function: FixtureFunction[_P, _R] | None = None,
     loop_scope: _ScopeName | None = None,
     **kwargs: Any,
-) -> FixtureFunction | FixtureFunctionMarker:
+) -> (
+    FixtureFunction[_P, _R]
+    | Callable[[FixtureFunction[_P, _R]], FixtureFunction[_P, _R]]
+):
     if fixture_function is not None:
         _make_asyncio_fixture_function(fixture_function, loop_scope)
         return pytest.fixture(fixture_function, **kwargs)
@@ -155,7 +165,7 @@ def fixture(
     else:
 
         @functools.wraps(fixture)
-        def inner(fixture_function: FixtureFunction) -> FixtureFunction:
+        def inner(fixture_function: FixtureFunction[_P, _R]) -> FixtureFunction[_P, _R]:
             return fixture(fixture_function, loop_scope=loop_scope, **kwargs)
 
         return inner
@@ -217,9 +227,15 @@ def pytest_configure(config: Config) -> None:
 def pytest_report_header(config: Config) -> list[str]:
     """Add asyncio config to pytest header."""
     mode = _get_asyncio_mode(config)
-    default_loop_scope = config.getini("asyncio_default_fixture_loop_scope")
+    default_fixture_loop_scope = config.getini("asyncio_default_fixture_loop_scope")
+    default_test_loop_scope = _get_default_test_loop_scope(config)
+    header = [
+        f"mode={mode}",
+        f"asyncio_default_fixture_loop_scope={default_fixture_loop_scope}",
+        f"asyncio_default_test_loop_scope={default_test_loop_scope}",
+    ]
     return [
-        f"asyncio: mode={mode}, asyncio_default_fixture_loop_scope={default_loop_scope}"
+        "asyncio: " + ", ".join(header),
     ]
 
 
@@ -667,7 +683,7 @@ _fixture_scope_by_collector_type: Mapping[type[pytest.Collector], _ScopeName] =
 
 # A stack used to push package-scoped loops during collection of a package
 # and pop those loops during collection of a Module
-__package_loop_stack: list[FixtureFunctionMarker | FixtureFunction] = []
+__package_loop_stack: list[Callable[..., Any]] = []
 
 
 @pytest.hookimpl
@@ -807,7 +823,8 @@ def pytest_generate_tests(metafunc: Metafunc) -> None:
     marker = metafunc.definition.get_closest_marker("asyncio")
     if not marker:
         return
-    scope = _get_marked_loop_scope(marker)
+    default_loop_scope = _get_default_test_loop_scope(metafunc.config)
+    scope = _get_marked_loop_scope(marker, default_loop_scope)
     if scope == "function":
         return
     event_loop_node = _retrieve_scope_root(metafunc.definition, scope)
@@ -1078,7 +1095,8 @@ def pytest_runtest_setup(item: pytest.Item) -> None:
     marker = item.get_closest_marker("asyncio")
     if marker is None:
         return
-    scope = _get_marked_loop_scope(marker)
+    default_loop_scope = _get_default_test_loop_scope(item.config)
+    scope = _get_marked_loop_scope(marker, default_loop_scope)
     if scope != "function":
         parent_node = _retrieve_scope_root(item, scope)
         event_loop_fixture_id = parent_node.stash[_event_loop_fixture_id]
@@ -1108,7 +1126,9 @@ Please use the "loop_scope" argument instead.
 """
 
 
-def _get_marked_loop_scope(asyncio_marker: Mark) -> _ScopeName:
+def _get_marked_loop_scope(
+    asyncio_marker: Mark, default_loop_scope: _ScopeName
+) -> _ScopeName:
     assert asyncio_marker.name == "asyncio"
     if asyncio_marker.args or (
         asyncio_marker.kwargs and set(asyncio_marker.kwargs) - {"loop_scope", "scope"}
@@ -1119,12 +1139,18 @@ def _get_marked_loop_scope(asyncio_marker: Mark) -> _ScopeName:
             raise pytest.UsageError(_DUPLICATE_LOOP_SCOPE_DEFINITION_ERROR)
         warnings.warn(PytestDeprecationWarning(_MARKER_SCOPE_KWARG_DEPRECATION_WARNING))
     scope = asyncio_marker.kwargs.get("loop_scope") or asyncio_marker.kwargs.get(
-        "scope", "function"
+        "scope"
     )
+    if scope is None:
+        scope = default_loop_scope
     assert scope in {"function", "class", "module", "package", "session"}
     return scope
 
 
+def _get_default_test_loop_scope(config: Config) -> _ScopeName:
+    return config.getini("asyncio_default_test_loop_scope")
+
+
 def _retrieve_scope_root(item: Collector | Item, scope: str) -> Collector:
     node_type_by_scope = {
         "class": Class,
@@ -1164,10 +1190,14 @@ def _provide_event_loop() -> Iterator[asyncio.AbstractEventLoop]:
     try:
         yield loop
     finally:
-        try:
-            loop.run_until_complete(loop.shutdown_asyncgens())
-        finally:
-            loop.close()
+        # cleanup the event loop if it hasn't been cleaned up already
+        if not loop.is_closed():
+            try:
+                loop.run_until_complete(loop.shutdown_asyncgens())
+            except Exception as e:
+                warnings.warn(f"Error cleaning up asyncio loop: {e}", RuntimeWarning)
+            finally:
+                loop.close()
 
 
 @pytest.fixture(scope="session")
